# frozen_string_literal: true

require 'json'
require 'open3'

# bindings for sysrc
class Sysrc
  def self.set(key, operation, value)
    raise unless ['=', '+=', '-='].include? operation

    cmd = format('sysrc %<k>s%<o>s%<v>s', { k: key, o: operation, v: value })
    _output, status = execute(cmd)
    status
  end

  def self.get(key)
    cmd = format('sysrc %<k>s', { k: key })
    output, _status = execute(cmd)
    output.chop.split.drop(1)
  end

  def self.execute(command)
    shell_env = 'LANG=C'
    cmd = "#{shell_env} #{command}"
    stdout, _stderr, status = Open3.capture3(cmd)
    [stdout, status.exitstatus.zero?]
  end
end
